[Libreoffice-commits] .: vcl/aqua vcl/generic vcl/headless vcl/inc vcl/ios vcl/source vcl/unx vcl/win

Miklos Vajna vmiklos at kemper.freedesktop.org
Wed Jun 20 01:56:31 PDT 2012


 vcl/aqua/source/gdi/salatslayout.cxx        |   12 +++----
 vcl/aqua/source/gdi/salgdi.cxx              |   16 +++++-----
 vcl/generic/glyphs/gcach_ftyp.cxx           |    2 -
 vcl/generic/glyphs/gcach_ftyp.hxx           |    6 +--
 vcl/generic/glyphs/glyphcache.cxx           |    2 -
 vcl/generic/print/genpspgraphics.cxx        |   24 +++++++--------
 vcl/headless/svptext.cxx                    |   16 +++++-----
 vcl/inc/aqua/salgdi.h                       |   12 +++----
 vcl/inc/generic/genpspgraphics.h            |    8 ++---
 vcl/inc/headless/svpgdi.hxx                 |    8 ++---
 vcl/inc/ios/salcoretextfontutils.hxx        |    4 +-
 vcl/inc/ios/salgdi.h                        |   10 +++---
 vcl/inc/outdev.h                            |   14 ++++----
 vcl/inc/outfont.hxx                         |   40 ++++++++++++-------------
 vcl/inc/salgdi.hxx                          |   10 +++---
 vcl/inc/sallayout.hxx                       |   12 +++----
 vcl/inc/unx/salgdi.h                        |    8 ++---
 vcl/inc/win/salgdi.h                        |   12 +++----
 vcl/ios/source/gdi/salcoretextfontutils.cxx |    4 +-
 vcl/ios/source/gdi/salgdi.cxx               |   10 +++---
 vcl/ios/source/gdi/salgdicommon.cxx         |    2 -
 vcl/source/gdi/outdev3.cxx                  |   44 ++++++++++++++--------------
 vcl/source/gdi/pdffontcache.cxx             |    6 +--
 vcl/source/gdi/pdffontcache.hxx             |    6 +--
 vcl/source/gdi/pdfwriter_impl.cxx           |   32 ++++++++++----------
 vcl/source/gdi/pdfwriter_impl.hxx           |   16 +++++-----
 vcl/source/gdi/sallayout.cxx                |    8 ++---
 vcl/unx/generic/gdi/salgdi3.cxx             |   16 +++++-----
 vcl/win/source/gdi/salgdi3.cxx              |   20 ++++++------
 vcl/win/source/gdi/winlayout.cxx            |    4 +-
 30 files changed, 192 insertions(+), 192 deletions(-)

New commits:
commit ddb89645e4e5b0ce2e5f07a8d3fd37404d597010
Author: Norbert Thiebaud <nthiebaud at gmail.com>
Date:   Tue Jun 19 06:24:37 2012 -0500

    Rename the class ImplFontData into PhysicalFontFace
    
    Change-Id: I402481e7c6ea605c8ccfdf6cb08166859b37e8de

diff --git a/vcl/generic/glyphs/gcach_ftyp.cxx b/vcl/generic/glyphs/gcach_ftyp.cxx
index 9cd88a4..9da8993 100644
--- a/vcl/generic/glyphs/gcach_ftyp.cxx
+++ b/vcl/generic/glyphs/gcach_ftyp.cxx
@@ -640,7 +640,7 @@ ServerFont* FreetypeManager::CreateFont( const FontSelectPattern& rFSD )
 // =======================================================================
 
 ImplFTSFontData::ImplFTSFontData( FtFontInfo* pFI, const ImplDevFontAttributes& rDFA )
-:   ImplFontData( rDFA, IFTSFONT_MAGIC ),
+:   PhysicalFontFace( rDFA, IFTSFONT_MAGIC ),
     mpFtFontInfo( pFI )
 {
     mbDevice        = false;
diff --git a/vcl/generic/glyphs/gcach_ftyp.hxx b/vcl/generic/glyphs/gcach_ftyp.hxx
index 7992672..0bd38e6 100644
--- a/vcl/generic/glyphs/gcach_ftyp.hxx
+++ b/vcl/generic/glyphs/gcach_ftyp.hxx
@@ -176,7 +176,7 @@ private:
 
 // -----------------------------------------------------------------------
 
-class ImplFTSFontData : public ImplFontData
+class ImplFTSFontData : public PhysicalFontFace
 {
 private:
     FtFontInfo*             mpFtFontInfo;
@@ -188,10 +188,10 @@ public:
     FtFontInfo*             GetFtFontInfo() const { return mpFtFontInfo; }
 
     virtual ImplFontEntry*  CreateFontInstance( FontSelectPattern& ) const;
-    virtual ImplFontData*   Clone() const   { return new ImplFTSFontData( *this ); }
+    virtual PhysicalFontFace* Clone() const   { return new ImplFTSFontData( *this ); }
     virtual sal_IntPtr      GetFontId() const { return mpFtFontInfo->GetFontId(); }
 
-    static bool             CheckFontData( const ImplFontData& r ) { return r.CheckMagic( IFTSFONT_MAGIC ); }
+    static bool             CheckFontData( const PhysicalFontFace& r ) { return r.CheckMagic( IFTSFONT_MAGIC ); }
 };
 
 // -----------------------------------------------------------------------
diff --git a/vcl/generic/glyphs/glyphcache.cxx b/vcl/generic/glyphs/glyphcache.cxx
index b48b415..66dc237 100644
--- a/vcl/generic/glyphs/glyphcache.cxx
+++ b/vcl/generic/glyphs/glyphcache.cxx
@@ -211,7 +211,7 @@ ServerFont* GlyphCache::CacheFont( const FontSelectPattern& rFontSelData )
 
     // the FontList's key mpFontData member is reinterpreted as font id
     FontSelectPattern aFontSelData = rFontSelData;
-    aFontSelData.mpFontData = reinterpret_cast<ImplFontData*>( nFontId );
+    aFontSelData.mpFontData = reinterpret_cast<PhysicalFontFace*>( nFontId );
     FontList::iterator it = maFontList.find( aFontSelData );
     if( it != maFontList.end() )
     {
diff --git a/vcl/inc/aqua/salgdi.h b/vcl/inc/aqua/salgdi.h
index 271b63e..0788095 100644
--- a/vcl/inc/aqua/salgdi.h
+++ b/vcl/inc/aqua/salgdi.h
@@ -50,14 +50,14 @@ class ImplDevFontAttributes;
 struct CGRect;
 
 // mac specific physically available font face
-class ImplMacFontData : public ImplFontData
+class ImplMacFontData : public PhysicalFontFace
 {
 public:
     ImplMacFontData( const ImplDevFontAttributes&, ATSUFontID );
 
     virtual ~ImplMacFontData();
 
-    virtual ImplFontData*   Clone() const;
+    virtual PhysicalFontFace*   Clone() const;
     virtual ImplFontEntry*  CreateFontInstance( FontSelectPattern& ) const;
     virtual sal_IntPtr      GetFontId() const;
 
@@ -298,7 +298,7 @@ public:
     // implementation note: encoding 0 with glyph id 0 should be added implicitly
     // as "undefined character"
     virtual sal_Bool            CreateFontSubset( const rtl::OUString& rToFile,
-                                              const ImplFontData* pFont,
+                                              const PhysicalFontFace* pFont,
                                               long* pGlyphIDs,
                                               sal_uInt8* pEncoding,
                                               sal_Int32* pWidths,
@@ -313,7 +313,7 @@ public:
     // glyphs with only a name) exist it is set to the corresponding
     // map for non encoded glyphs; the encoding vector contains -1
     // as encoding for these cases
-    virtual const Ucs2SIntMap* GetFontEncodingVector( const ImplFontData*, const Ucs2OStrMap** ppNonEncoded );
+    virtual const Ucs2SIntMap* GetFontEncodingVector( const PhysicalFontFace*, const Ucs2OStrMap** ppNonEncoded );
 
     // GetEmbedFontData: gets the font data for a font marked
     // embeddable by GetDevFontList or NULL in case of error
@@ -322,7 +322,7 @@ public:
     //                      pWidths MUST support at least 256 members;
     //             rInfo: additional outgoing information
     //             pDataLen: out parameter, contains the byte length of the returned buffer
-    virtual const void* GetEmbedFontData( const ImplFontData*,
+    virtual const void* GetEmbedFontData( const PhysicalFontFace*,
                                           const sal_Ucs* pUnicodes,
                                           sal_Int32* pWidths,
                                           FontSubsetInfo& rInfo,
@@ -330,7 +330,7 @@ public:
     // frees the font data again
     virtual void            FreeEmbedFontData( const void* pData, long nDataLen );
 
-    virtual void            GetGlyphWidths( const ImplFontData*,
+    virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
                                             Int32Vector& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc );
diff --git a/vcl/inc/generic/genpspgraphics.h b/vcl/inc/generic/genpspgraphics.h
index c098496..177f09a 100644
--- a/vcl/inc/generic/genpspgraphics.h
+++ b/vcl/inc/generic/genpspgraphics.h
@@ -107,21 +107,21 @@ public:
     virtual bool            AddTempDevFont( ImplDevFontList*, const rtl::OUString& rFileURL, const rtl::OUString& rFontName );
 
     virtual sal_Bool            CreateFontSubset( const rtl::OUString& rToFile,
-                                              const ImplFontData*,
+                                              const PhysicalFontFace*,
                                               sal_Int32* pGlyphIDs,
                                               sal_uInt8* pEncoding,
                                               sal_Int32* pWidths,
                                               int nGlyphs,
                                               FontSubsetInfo& rInfo
                                               );
-    virtual const Ucs2SIntMap* GetFontEncodingVector( const ImplFontData*, const Ucs2OStrMap** ppNonEncoded );
-    virtual const void*     GetEmbedFontData( const ImplFontData*,
+    virtual const Ucs2SIntMap* GetFontEncodingVector( const PhysicalFontFace*, const Ucs2OStrMap** ppNonEncoded );
+    virtual const void*     GetEmbedFontData( const PhysicalFontFace*,
                                               const sal_Ucs* pUnicodes,
                                               sal_Int32* pWidths,
                                               FontSubsetInfo& rInfo,
                                               long* pDataLen );
     virtual void            FreeEmbedFontData( const void* pData, long nDataLen );
-    virtual void            GetGlyphWidths( const ImplFontData*,
+    virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
                                             Int32Vector& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc );
diff --git a/vcl/inc/headless/svpgdi.hxx b/vcl/inc/headless/svpgdi.hxx
index 906a76e..9f2f913 100644
--- a/vcl/inc/headless/svpgdi.hxx
+++ b/vcl/inc/headless/svpgdi.hxx
@@ -108,21 +108,21 @@ public:
     virtual void            GetDevFontSubstList( OutputDevice* );
     virtual bool            AddTempDevFont( ImplDevFontList*, const rtl::OUString& rFileURL, const rtl::OUString& rFontName );
     virtual sal_Bool            CreateFontSubset( const rtl::OUString& rToFile,
-                                              const ImplFontData*,
+                                              const PhysicalFontFace*,
                                               sal_Int32* pGlyphIDs,
                                               sal_uInt8* pEncoding,
                                               sal_Int32* pWidths,
                                               int nGlyphs,
                                               FontSubsetInfo& rInfo
                                               );
-    virtual const Ucs2SIntMap* GetFontEncodingVector( const ImplFontData*, const Ucs2OStrMap** ppNonEncoded );
-    virtual const void* GetEmbedFontData( const ImplFontData*,
+    virtual const Ucs2SIntMap* GetFontEncodingVector( const PhysicalFontFace*, const Ucs2OStrMap** ppNonEncoded );
+    virtual const void* GetEmbedFontData( const PhysicalFontFace*,
                                           const sal_Ucs* pUnicodes,
                                           sal_Int32* pWidths,
                                           FontSubsetInfo& rInfo,
                                           long* pDataLen );
     virtual void            FreeEmbedFontData( const void* pData, long nDataLen );
-    virtual void            GetGlyphWidths( const ImplFontData*,
+    virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
                                             Int32Vector& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc );
diff --git a/vcl/inc/ios/salcoretextfontutils.hxx b/vcl/inc/ios/salcoretextfontutils.hxx
index bcc399c..1490e08 100644
--- a/vcl/inc/ios/salcoretextfontutils.hxx
+++ b/vcl/inc/ios/salcoretextfontutils.hxx
@@ -39,12 +39,12 @@ class ImplDevFontList;
 #include "outfont.hxx"
 #include "impfont.hxx"
 
-class ImplCoreTextFontData : public ImplFontData
+class ImplCoreTextFontData : public PhysicalFontFace
 {
 public:
     ImplCoreTextFontData(const ImplDevFontAttributes&, CTFontRef font);
     virtual ~ImplCoreTextFontData();
-    virtual ImplFontData* Clone() const;
+    virtual PhysicalFontFace* Clone() const;
     virtual ImplFontEntry* CreateFontInstance( FontSelectPattern& ) const;
     virtual sal_IntPtr GetFontId() const { return (sal_IntPtr)m_CTFontRef;};
     CTFontRef GetCTFont() const { return m_CTFontRef; };
diff --git a/vcl/inc/ios/salgdi.h b/vcl/inc/ios/salgdi.h
index 2828b4e..1d9ef63 100644
--- a/vcl/inc/ios/salgdi.h
+++ b/vcl/inc/ios/salgdi.h
@@ -239,7 +239,7 @@ public:
     // implementation note: encoding 0 with glyph id 0 should be added implicitly
     // as "undefined character"
     virtual sal_Bool CreateFontSubset( const rtl::OUString& rToFile,
-                                       const ImplFontData* pFont,
+                                       const PhysicalFontFace* pFont,
                                        long* pGlyphIDs,
                                        sal_uInt8* pEncoding,
                                        sal_Int32* pWidths,
@@ -253,7 +253,7 @@ public:
     // glyphs with only a name) exist it is set to the corresponding
     // map for non encoded glyphs; the encoding vector contains -1
     // as encoding for these cases
-    virtual const Ucs2SIntMap* GetFontEncodingVector( const ImplFontData*, const Ucs2OStrMap** ppNonEncoded );
+    virtual const Ucs2SIntMap* GetFontEncodingVector( const PhysicalFontFace*, const Ucs2OStrMap** ppNonEncoded );
 
     // GetEmbedFontData: gets the font data for a font marked
     // embeddable by GetDevFontList or NULL in case of error
@@ -262,7 +262,7 @@ public:
     //                      pWidths MUST support at least 256 members;
     //             rInfo: additional outgoing information
     //             pDataLen: out parameter, contains the byte length of the returned buffer
-    virtual const void* GetEmbedFontData( const ImplFontData*,
+    virtual const void* GetEmbedFontData( const PhysicalFontFace*,
                                           const sal_Ucs* pUnicodes,
                                           sal_Int32* pWidths,
                                           FontSubsetInfo& rInfo,
@@ -270,7 +270,7 @@ public:
     // frees the font data again
     virtual void FreeEmbedFontData( const void* pData, long nDataLen );
 
-    virtual void GetGlyphWidths( const ImplFontData*,
+    virtual void GetGlyphWidths( const PhysicalFontFace*,
                                  bool bVertical,
                                  Int32Vector& rWidths,
                                  Ucs2UIntMap& rUnicodeEnc );
@@ -297,7 +297,7 @@ private:
     void Pattern50Fill();
     UInt32 getState( ControlState nState );
     UInt32 getTrackState( ControlState nState );
-    bool GetRawFontData( const ImplFontData* pFontData,
+    bool GetRawFontData( const PhysicalFontFace* pFontData,
                          std::vector<unsigned char>& rBuffer,
                          bool* pJustCFF );
 };
diff --git a/vcl/inc/outdev.h b/vcl/inc/outdev.h
index 090fd88..614bfd7 100644
--- a/vcl/inc/outdev.h
+++ b/vcl/inc/outdev.h
@@ -70,19 +70,19 @@ public:
     bool                IsScalable() const       { return mpFirst->IsScalable(); }
     int                 GetMinQuality() const    { return mnMinQuality; }
 
-    bool                AddFontFace( ImplFontData* );
+    bool                AddFontFace( PhysicalFontFace* );
     void                InitMatchData( const utl::FontSubstConfiguration&,
                             const String& rSearchName );
-    ImplFontData*       FindBestFontFace( const FontSelectPattern& rFSD ) const;
+    PhysicalFontFace*   FindBestFontFace( const FontSelectPattern& rFSD ) const;
 
     void                GetFontHeights( std::set<int>& rHeights ) const;
     void                UpdateDevFontList( ImplGetDevFontList& ) const;
     void                UpdateCloneFontList( ImplDevFontList&,
-                            bool bScalable, bool bEmbeddable ) const;
+                                             bool bScalable, bool bEmbeddable ) const;
 
 private:
 friend class ImplDevFontList; // TODO: remove soon
-    ImplFontData*       mpFirst;            // linked list of physical font faces
+    PhysicalFontFace*   mpFirst;            // linked list of physical font faces
     String              maName;             // Fontname (original font family name)
     String              maSearchName;       // normalized font family name
     String              maMapNames;         // fontname aliases
@@ -106,12 +106,12 @@ friend class ImplDevFontList; // TODO: remove soon
 class ImplGetDevFontList
 {
 private:
-    std::vector<ImplFontData*> maDevFontVector;
+    std::vector<PhysicalFontFace*> maDevFontVector;
 
 public:
                         ImplGetDevFontList()        { maDevFontVector.reserve(1024); }
-    void                Add( ImplFontData* pFace )  { maDevFontVector.push_back( pFace ); }
-    ImplFontData*       Get( int nIndex ) const     { return maDevFontVector[ nIndex ]; }
+    void                Add( PhysicalFontFace* pFace )  { maDevFontVector.push_back( pFace ); }
+    PhysicalFontFace*   Get( int nIndex ) const     { return maDevFontVector[ nIndex ]; }
     int                 Count() const               { return maDevFontVector.size(); }
 };
 
diff --git a/vcl/inc/salgdi.hxx b/vcl/inc/salgdi.hxx
index 0a68c20..00e37e5 100644
--- a/vcl/inc/salgdi.hxx
+++ b/vcl/inc/salgdi.hxx
@@ -49,7 +49,7 @@ class SalBitmap;
 class FontSelectPattern;
 class ImplFontMetricData;
 struct ImplKernPairData;
-class ImplFontData;
+class PhysicalFontFace;
 class ImplFontCharMap;
 class SalLayout;
 class ImplLayoutArgs;
@@ -256,7 +256,7 @@ public:
     // implementation note: encoding 0 with glyph id 0 should be added implicitly
     // as "undefined character"
     virtual sal_Bool            CreateFontSubset( const rtl::OUString& rToFile,
-                                              const ImplFontData* pFont,
+                                              const PhysicalFontFace* pFont,
                                               sal_Int32* pGlyphIDs,
                                               sal_uInt8* pEncoding,
                                               sal_Int32* pWidths,
@@ -271,7 +271,7 @@ public:
     // glyphs with only a name) exist it is set to the corresponding
     // map for non encoded glyphs; the encoding vector contains -1
     // as encoding for these cases
-    virtual const Ucs2SIntMap* GetFontEncodingVector( const ImplFontData*, const Ucs2OStrMap** ppNonEncoded ) = 0;
+    virtual const Ucs2SIntMap* GetFontEncodingVector( const PhysicalFontFace*, const Ucs2OStrMap** ppNonEncoded ) = 0;
 
     // GetEmbedFontData: gets the font data for a font marked
     // embeddable by GetDevFontList or NULL in case of error
@@ -282,7 +282,7 @@ public:
     //                      pWidths MUST support at least 256 members;
     //             rInfo: additional outgoing information
     //             pDataLen: out parameter, contains the byte length of the returned buffer
-    virtual const void* GetEmbedFontData( const ImplFontData* pFont,
+    virtual const void* GetEmbedFontData( const PhysicalFontFace* pFont,
                                           const sal_Ucs* pUnicodes,
                                           sal_Int32* pWidths,
                                           FontSubsetInfo& rInfo,
@@ -294,7 +294,7 @@ public:
     // in case of an embeddable font also fill the mapping
     // between unicode and glyph id
     // leave widths vector and mapping untouched in case of failure
-    virtual void            GetGlyphWidths( const ImplFontData* pFont,
+    virtual void            GetGlyphWidths( const PhysicalFontFace* pFont,
                                             bool bVertical,
                                             Int32Vector& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc ) = 0;
diff --git a/vcl/inc/sallayout.hxx b/vcl/inc/sallayout.hxx
index 85c04f0..7ed0c93 100644
--- a/vcl/inc/sallayout.hxx
+++ b/vcl/inc/sallayout.hxx
@@ -49,7 +49,7 @@ typedef unsigned short LanguageType;
 #include <vcl/vclenum.hxx>
 
 class SalGraphics;
-class ImplFontData;
+class PhysicalFontFace;
 
 #define MAX_FALLBACK 16
 
@@ -197,7 +197,7 @@ public:
     int             GetUnitsPerPixel() const                { return mnUnitsPerPixel; }
     int             GetOrientation() const                  { return mnOrientation; }
 
-    virtual const ImplFontData* GetFallbackFontData( sal_GlyphId ) const;
+    virtual const PhysicalFontFace* GetFallbackFontData( sal_GlyphId ) const;
 
     // methods using string indexing
     virtual int     GetTextBreak( long nMaxWidth, long nCharExtra=0, int nFactor=1 ) const = 0;
@@ -271,14 +271,14 @@ public:
 
     // used only by OutputDevice::ImplLayout, TODO: make friend
     explicit        MultiSalLayout( SalLayout& rBaseLayout,
-                         const ImplFontData* pBaseFont = NULL );
+                         const PhysicalFontFace* pBaseFont = NULL );
     virtual bool    AddFallback( SalLayout& rFallbackLayout,
-                         ImplLayoutRuns&, const ImplFontData* pFallbackFont );
+                         ImplLayoutRuns&, const PhysicalFontFace* pFallbackFont );
     virtual bool    LayoutText( ImplLayoutArgs& );
     virtual void    AdjustLayout( ImplLayoutArgs& );
     virtual void    InitFont() const;
 
-    virtual const ImplFontData* GetFallbackFontData( sal_GlyphId ) const;
+    virtual const PhysicalFontFace* GetFallbackFontData( sal_GlyphId ) const;
 
     void SetInComplete(bool bInComplete = true);
 
@@ -297,7 +297,7 @@ private:
 
 private:
     SalLayout*      mpLayouts[ MAX_FALLBACK ];
-    const ImplFontData* mpFallbackFonts[ MAX_FALLBACK ];
+    const PhysicalFontFace* mpFallbackFonts[ MAX_FALLBACK ];
     ImplLayoutRuns  maFallbackRuns[ MAX_FALLBACK ];
     int             mnLevel;
     bool            mbInComplete;
diff --git a/vcl/inc/unx/salgdi.h b/vcl/inc/unx/salgdi.h
index fd0ffbe..f52605a 100644
--- a/vcl/inc/unx/salgdi.h
+++ b/vcl/inc/unx/salgdi.h
@@ -269,21 +269,21 @@ public:
     virtual void            GetDevFontSubstList( OutputDevice* );
     virtual bool            AddTempDevFont( ImplDevFontList*, const rtl::OUString& rFileURL, const rtl::OUString& rFontName );
     virtual sal_Bool            CreateFontSubset( const rtl::OUString& rToFile,
-                                              const ImplFontData*,
+                                              const PhysicalFontFace*,
                                               sal_Int32* pGlyphIDs,
                                               sal_uInt8* pEncoding,
                                               sal_Int32* pWidths,
                                               int nGlyphs,
                                               FontSubsetInfo& rInfo
                                               );
-    virtual const Ucs2SIntMap* GetFontEncodingVector( const ImplFontData*, const Ucs2OStrMap** ppNonEncoded );
-    virtual const void* GetEmbedFontData( const ImplFontData*,
+    virtual const Ucs2SIntMap* GetFontEncodingVector( const PhysicalFontFace*, const Ucs2OStrMap** ppNonEncoded );
+    virtual const void* GetEmbedFontData( const PhysicalFontFace*,
                                           const sal_Ucs* pUnicodes,
                                           sal_Int32* pWidths,
                                           FontSubsetInfo& rInfo,
                                           long* pDataLen );
     virtual void            FreeEmbedFontData( const void* pData, long nDataLen );
-    virtual void            GetGlyphWidths( const ImplFontData*,
+    virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
                                             Int32Vector& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc );
diff --git a/vcl/inc/win/salgdi.h b/vcl/inc/win/salgdi.h
index 50d1015..f92849c 100644
--- a/vcl/inc/win/salgdi.h
+++ b/vcl/inc/win/salgdi.h
@@ -74,7 +74,7 @@ private:
 #endif
 
 // win32 specific physically available font face
-class ImplWinFontData : public ImplFontData
+class ImplWinFontData : public PhysicalFontFace
 {
 public:
     explicit                ImplWinFontData( const ImplDevFontAttributes&,
@@ -82,7 +82,7 @@ public:
                                 BYTE nPitchAndFamily  );
     virtual                 ~ImplWinFontData();
 
-    virtual ImplFontData*   Clone() const;
+    virtual PhysicalFontFace*   Clone() const;
     virtual ImplFontEntry*  CreateFontInstance( FontSelectPattern& ) const;
     virtual sal_IntPtr      GetFontId() const;
     void                    SetFontId( sal_IntPtr nId ) { mnId = nId; }
@@ -322,7 +322,7 @@ public:
     // implementation note: encoding 0 with glyph id 0 should be added implicitly
     // as "undefined character"
     virtual sal_Bool            CreateFontSubset( const rtl::OUString& rToFile,
-                                              const ImplFontData*,
+                                              const PhysicalFontFace*,
                                               long* pGlyphIDs,
                                               sal_uInt8* pEncoding,
                                               sal_Int32* pWidths,
@@ -337,7 +337,7 @@ public:
     // glyphs with only a name) exist it is set to the corresponding
     // map for non encoded glyphs; the encoding vector contains -1
     // as encoding for these cases
-    virtual const Ucs2SIntMap* GetFontEncodingVector( const ImplFontData*, const Ucs2OStrMap** ppNonEncoded );
+    virtual const Ucs2SIntMap* GetFontEncodingVector( const PhysicalFontFace*, const Ucs2OStrMap** ppNonEncoded );
 
     // GetEmbedFontData: gets the font data for a font marked
     // embeddable by GetDevFontList or NULL in case of error
@@ -346,14 +346,14 @@ public:
     //                      pWidths MUST support at least 256 members;
     //             rInfo: additional outgoing information
     //             pDataLen: out parameter, contains the byte length of the returned buffer
-    virtual const void* GetEmbedFontData( const ImplFontData*,
+    virtual const void* GetEmbedFontData( const PhysicalFontFace*,
                                           const sal_Ucs* pUnicodes,
                                           sal_Int32* pWidths,
                                           FontSubsetInfo& rInfo,
                                           long* pDataLen );
     // frees the font data again
     virtual void            FreeEmbedFontData( const void* pData, long nDataLen );
-    virtual void            GetGlyphWidths( const ImplFontData*,
+    virtual void            GetGlyphWidths( const PhysicalFontFace*,
                                             bool bVertical,
                                             Int32Vector& rWidths,
                                             Ucs2UIntMap& rUnicodeEnc );
diff --git a/vcl/ios/source/gdi/salcoretextfontutils.cxx b/vcl/ios/source/gdi/salcoretextfontutils.cxx
index 2d88c8d..5f6c23d 100644
--- a/vcl/ios/source/gdi/salcoretextfontutils.cxx
+++ b/vcl/ios/source/gdi/salcoretextfontutils.cxx
@@ -257,7 +257,7 @@ void SystemFontList::AnnounceFonts( ImplDevFontList& rFontList ) const
 }
 
 ImplCoreTextFontData::ImplCoreTextFontData( const ImplDevFontAttributes& rDFA, CTFontRef font )
-:   ImplFontData( rDFA, 0 )
+:   PhysicalFontFace( rDFA, 0 )
 ,   m_CTFontRef((CTFontRef)CFRetain(font))
 ,   m_pCharMap( NULL )
 ,   m_bHasOs2Table( false )
@@ -280,7 +280,7 @@ ImplCoreTextFontData::~ImplCoreTextFontData()
     }
 }
 
-ImplFontData* ImplCoreTextFontData::Clone() const
+PhysicalFontFace* ImplCoreTextFontData::Clone() const
 {
     ImplCoreTextFontData* pClone = new ImplCoreTextFontData(*this);
     if ( m_pCharMap )
diff --git a/vcl/ios/source/gdi/salgdicommon.cxx b/vcl/ios/source/gdi/salgdicommon.cxx
index 9ceefb2..0d5e855 100644
--- a/vcl/ios/source/gdi/salgdicommon.cxx
+++ b/vcl/ios/source/gdi/salgdicommon.cxx
@@ -144,7 +144,7 @@ static void AddPolyPolygonToPath( CGMutablePathRef xPath,
 }
 
 sal_Bool IosSalGraphics::CreateFontSubset( const rtl::OUString& rToFile,
-                                            const ImplFontData* pFontData,
+                                            const PhysicalFontFace* pFontData,
                                             long* pGlyphIDs, sal_uInt8* pEncoding,
                                             sal_Int32* pGlyphWidths, int nGlyphCount,
                                             FontSubsetInfo& rInfo )
diff --git a/vcl/source/gdi/outdev3.cxx b/vcl/source/gdi/outdev3.cxx
index 948fcc3..3459afc 100644
--- a/vcl/source/gdi/outdev3.cxx
+++ b/vcl/source/gdi/outdev3.cxx
@@ -740,7 +740,7 @@ static void ImplCalcType( sal_uLong& rType, FontWeight& rWeight, FontWidth& rWid
 
 // =======================================================================
 
-ImplFontData::ImplFontData( const ImplDevFontAttributes& rDFA, int nMagic )
+PhysicalFontFace::PhysicalFontFace( const ImplDevFontAttributes& rDFA, int nMagic )
 :   ImplDevFontAttributes( rDFA ),
     mnWidth(0),
     mnHeight(0),
@@ -756,7 +756,7 @@ ImplFontData::ImplFontData( const ImplDevFontAttributes& rDFA, int nMagic )
 
 // -----------------------------------------------------------------------
 
-StringCompare ImplFontData::CompareIgnoreSize( const ImplFontData& rOther ) const
+StringCompare PhysicalFontFace::CompareIgnoreSize( const PhysicalFontFace& rOther ) const
 {
     // compare their width, weight, italic and style name
     if( meWidthType < rOther.meWidthType )
@@ -780,7 +780,7 @@ StringCompare ImplFontData::CompareIgnoreSize( const ImplFontData& rOther ) cons
 
 // -----------------------------------------------------------------------
 
-StringCompare ImplFontData::CompareWithSize( const ImplFontData& rOther ) const
+StringCompare PhysicalFontFace::CompareWithSize( const PhysicalFontFace& rOther ) const
 {
     StringCompare eCompare = CompareIgnoreSize( rOther );
     if( eCompare != COMPARE_EQUAL )
@@ -810,7 +810,7 @@ public:
     const xub_Unicode*  mpTargetStyleName;
 };
 
-bool ImplFontData::IsBetterMatch( const FontSelectPattern& rFSD, FontMatchStatus& rStatus ) const
+bool PhysicalFontFace::IsBetterMatch( const FontSelectPattern& rFSD, FontMatchStatus& rStatus ) const
 {
     int nMatch = 0;
 
@@ -1040,7 +1040,7 @@ ImplDevFontListData::~ImplDevFontListData()
     // release all physical font faces
     while( mpFirst )
     {
-        ImplFontData* pFace = mpFirst;
+        PhysicalFontFace* pFace = mpFirst;
         mpFirst = pFace->GetNextFace();
         delete pFace;
     }
@@ -1048,7 +1048,7 @@ ImplDevFontListData::~ImplDevFontListData()
 
 // -----------------------------------------------------------------------
 
-bool ImplDevFontListData::AddFontFace( ImplFontData* pNewData )
+bool ImplDevFontListData::AddFontFace( PhysicalFontFace* pNewData )
 {
     pNewData->mpNext = NULL;
 
@@ -1114,8 +1114,8 @@ bool ImplDevFontListData::AddFontFace( ImplFontData* pNewData )
 
     // insert new physical font face into linked list
     // TODO: get rid of linear search?
-    ImplFontData* pData;
-    ImplFontData** ppHere = &mpFirst;
+    PhysicalFontFace* pData;
+    PhysicalFontFace** ppHere = &mpFirst;
     for(; (pData=*ppHere) != NULL; ppHere=&pData->mpNext )
     {
         StringCompare eComp = pNewData->CompareWithSize( *pData );
@@ -1167,7 +1167,7 @@ void ImplDevFontListData::InitMatchData( const utl::FontSubstConfiguration& rFon
 
 // -----------------------------------------------------------------------
 
-ImplFontData* ImplDevFontListData::FindBestFontFace( const FontSelectPattern& rFSD ) const
+PhysicalFontFace* ImplDevFontListData::FindBestFontFace( const FontSelectPattern& rFSD ) const
 {
     if( !mpFirst )
         return NULL;
@@ -1182,8 +1182,8 @@ ImplFontData* ImplDevFontListData::FindBestFontFace( const FontSelectPattern& rF
         pTargetStyleName = rSearchName.GetBuffer() + maSearchName.Len() + 1;
 
     // linear search, TODO: improve?
-    ImplFontData* pFontFace = mpFirst;
-    ImplFontData* pBestFontFace = pFontFace;
+    PhysicalFontFace* pFontFace = mpFirst;
+    PhysicalFontFace* pBestFontFace = pFontFace;
     FontMatchStatus aFontMatchStatus = {0,0,0, pTargetStyleName};
     for(; pFontFace; pFontFace = pFontFace->GetNextFace() )
         if( pFontFace->IsBetterMatch( rFSD, aFontMatchStatus ) )
@@ -1198,8 +1198,8 @@ ImplFontData* ImplDevFontListData::FindBestFontFace( const FontSelectPattern& rF
 // meaning different font attributes, but not different fonts sizes
 void ImplDevFontListData::UpdateDevFontList( ImplGetDevFontList& rDevFontList ) const
 {
-    ImplFontData* pPrevFace = NULL;
-    for( ImplFontData* pFace = mpFirst; pFace; pFace = pFace->GetNextFace() )
+    PhysicalFontFace* pPrevFace = NULL;
+    for( PhysicalFontFace* pFace = mpFirst; pFace; pFace = pFace->GetNextFace() )
     {
         if( !pPrevFace || pFace->CompareIgnoreSize( *pPrevFace ) )
             rDevFontList.Add( pFace );
@@ -1212,7 +1212,7 @@ void ImplDevFontListData::UpdateDevFontList( ImplGetDevFontList& rDevFontList )
 void ImplDevFontListData::GetFontHeights( std::set<int>& rHeights ) const
 {
     // add all available font heights
-    for( const ImplFontData* pFace = mpFirst; pFace; pFace = pFace->GetNextFace() )
+    for( const PhysicalFontFace* pFace = mpFirst; pFace; pFace = pFace->GetNextFace() )
         rHeights.insert( pFace->GetHeight() );
 }
 
@@ -1221,14 +1221,14 @@ void ImplDevFontListData::GetFontHeights( std::set<int>& rHeights ) const
 void ImplDevFontListData::UpdateCloneFontList( ImplDevFontList& rDevFontList,
     bool bScalable, bool bEmbeddable ) const
 {
-    for( ImplFontData* pFace = mpFirst; pFace; pFace = pFace->GetNextFace() )
+    for( PhysicalFontFace* pFace = mpFirst; pFace; pFace = pFace->GetNextFace() )
     {
         if( bScalable && !pFace->IsScalable() )
             continue;
         if( bEmbeddable && !pFace->IsEmbeddable() && !pFace->IsSubsettable() )
             continue;
 
-        ImplFontData* pClonedFace = pFace->Clone();
+        PhysicalFontFace* pClonedFace = pFace->Clone();
         rDevFontList.Add( pClonedFace );
     }
 }
@@ -1481,7 +1481,7 @@ ImplDevFontListData* ImplDevFontList::GetGlyphFallbackFont( FontSelectPattern& r
 
 // -----------------------------------------------------------------------
 
-void ImplDevFontList::Add( ImplFontData* pNewData )
+void ImplDevFontList::Add( PhysicalFontFace* pNewData )
 {
     int nAliasQuality = pNewData->mnQuality - 100;
     String aMapNames = pNewData->maMapNames;
@@ -2177,7 +2177,7 @@ FontSelectPattern::FontSelectPattern( const Font& rFont,
 
 // -----------------------------------------------------------------------
 // NOTE: this ctor is still used on Windows. Do not remove.
-FontSelectPattern::FontSelectPattern( const ImplFontData& rFontData,
+FontSelectPattern::FontSelectPattern( const PhysicalFontFace& rFontData,
     const Size& rSize, float fExactHeight, int nOrientation, bool bVertical )
 :   ImplFontAttributes( rFontData ),
     mnWidth( rSize.Width() ),
@@ -2373,7 +2373,7 @@ ImplFontEntry* ImplFontCache::GetFontEntry( ImplDevFontList* pFontList,
         }
     }
 
-    ImplFontData* pFontData = NULL;
+    PhysicalFontFace* pFontData = NULL;
 
     if (!pEntry && pFontFamily)// no cache hit => find the best matching physical font face
     {
@@ -7231,7 +7231,7 @@ FontInfo OutputDevice::GetDevFont( int nDevFontIndex ) const
     int nCount = GetDevFontCount();
     if( nDevFontIndex < nCount )
     {
-        const ImplFontData& rData = *mpGetDevFontList->Get( nDevFontIndex );
+        const PhysicalFontFace& rData = *mpGetDevFontList->Get( nDevFontIndex );
         aFontInfo.SetName( rData.maName );
         aFontInfo.SetStyleName( rData.maStyleName );
         aFontInfo.SetCharSet( rData.mbSymbolFlag ? RTL_TEXTENCODING_SYMBOL : RTL_TEXTENCODING_UNICODE );
@@ -8096,10 +8096,10 @@ sal_Bool OutputDevice::GetFontCharMap( FontCharMap& rFontCharMap ) const
     static const int NMAXITEMS = 16;
     static int nUsedItems = 0, nCurItem = 0;
 
-    struct CharMapCacheItem { const ImplFontData* mpFontData; FontCharMap maCharMap; };
+    struct CharMapCacheItem { const PhysicalFontFace* mpFontData; FontCharMap maCharMap; };
     static CharMapCacheItem aCache[ NMAXITEMS ];
 
-    const ImplFontData* pFontData = mpFontEntry->maFontSelData.mpFontData;
+    const PhysicalFontFace* pFontData = mpFontEntry->maFontSelData.mpFontData;
 
     int i;
     for( i = nUsedItems; --i >= 0; )
diff --git a/vcl/source/gdi/pdffontcache.cxx b/vcl/source/gdi/pdffontcache.cxx
index 13fc383..974beb4 100644
--- a/vcl/source/gdi/pdffontcache.cxx
+++ b/vcl/source/gdi/pdffontcache.cxx
@@ -34,14 +34,14 @@
 
 using namespace vcl;
 
-PDFFontCache::FontIdentifier::FontIdentifier( const ImplFontData* pFont, bool bVertical ) :
+PDFFontCache::FontIdentifier::FontIdentifier( const PhysicalFontFace* pFont, bool bVertical ) :
     m_nFontId( pFont->GetFontId() ),
     m_nMagic( pFont->GetFontMagic() ),
     m_bVertical( bVertical )
 {
 }
 
-PDFFontCache::FontData& PDFFontCache::getFont( const ImplFontData* pFont, bool bVertical )
+PDFFontCache::FontData& PDFFontCache::getFont( const PhysicalFontFace* pFont, bool bVertical )
 {
     FontIdentifier aId( pFont, bVertical );
     FontToIndexMap::iterator it = m_aFontToIndex.find( aId );
@@ -52,7 +52,7 @@ PDFFontCache::FontData& PDFFontCache::getFont( const ImplFontData* pFont, bool b
     return m_aFonts.back();
 }
 
-sal_Int32 PDFFontCache::getGlyphWidth( const ImplFontData* pFont, sal_GlyphId nGlyph, bool bVertical, SalGraphics* pGraphics )
+sal_Int32 PDFFontCache::getGlyphWidth( const PhysicalFontFace* pFont, sal_GlyphId nGlyph, bool bVertical, SalGraphics* pGraphics )
 {
     sal_Int32 nWidth = 0;
     FontData& rFontData( getFont( pFont, bVertical ) );
diff --git a/vcl/source/gdi/pdffontcache.hxx b/vcl/source/gdi/pdffontcache.hxx
index f607f10..6b14f28 100644
--- a/vcl/source/gdi/pdffontcache.hxx
+++ b/vcl/source/gdi/pdffontcache.hxx
@@ -44,7 +44,7 @@ namespace vcl
             int             m_nMagic;
             bool            m_bVertical;
 
-            FontIdentifier( const ImplFontData*, bool bVertical );
+            FontIdentifier( const PhysicalFontFace*, bool bVertical );
             FontIdentifier() : m_nFontId(0), m_nMagic(0), m_bVertical( false ) {}
 
             bool operator==( const FontIdentifier& rRight ) const
@@ -70,12 +70,12 @@ namespace vcl
         std::vector< FontData >     m_aFonts;
         FontToIndexMap              m_aFontToIndex;
 
-        FontData& getFont( const ImplFontData*, bool bVertical );
+        FontData& getFont( const PhysicalFontFace*, bool bVertical );
         public:
         PDFFontCache() {}
         ~PDFFontCache() {}
 
-        sal_Int32 getGlyphWidth( const ImplFontData*, sal_GlyphId, bool bVertical, SalGraphics* );
+        sal_Int32 getGlyphWidth( const PhysicalFontFace*, sal_GlyphId, bool bVertical, SalGraphics* );
     };
 }
 
diff --git a/vcl/source/gdi/pdfwriter_impl.cxx b/vcl/source/gdi/pdfwriter_impl.cxx
index 5d7873c..07af727 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -2235,7 +2235,7 @@ OutputDevice* PDFWriterImpl::getReferenceDevice()
     return m_pReferenceDevice;
 }
 
-class ImplPdfBuiltinFontData : public ImplFontData
+class ImplPdfBuiltinFontData : public PhysicalFontFace
 {
 private:
     const PDFWriterImpl::BuiltinFont& mrBuiltin;
@@ -2245,12 +2245,12 @@ public:
                                         ImplPdfBuiltinFontData( const PDFWriterImpl::BuiltinFont& );
     const PDFWriterImpl::BuiltinFont*   GetBuiltinFont() const  { return &mrBuiltin; }
 
-    virtual ImplFontData*               Clone() const { return new ImplPdfBuiltinFontData(*this); }
+    virtual PhysicalFontFace*           Clone() const { return new ImplPdfBuiltinFontData(*this); }
     virtual ImplFontEntry*              CreateFontInstance( FontSelectPattern& ) const;
     virtual sal_IntPtr                  GetFontId() const { return reinterpret_cast<sal_IntPtr>(&mrBuiltin); }
 };
 
-inline const ImplPdfBuiltinFontData* GetPdfFontData( const ImplFontData* pFontData )
+inline const ImplPdfBuiltinFontData* GetPdfFontData( const PhysicalFontFace* pFontData )
 {
     const ImplPdfBuiltinFontData* pFD = NULL;
     if( pFontData && pFontData->CheckMagic( ImplPdfBuiltinFontData::PDF_FONT_MAGIC ) )
@@ -2279,7 +2279,7 @@ static ImplDevFontAttributes GetDevFontAttributes( const PDFWriterImpl::BuiltinF
 }
 
 ImplPdfBuiltinFontData::ImplPdfBuiltinFontData( const PDFWriterImpl::BuiltinFont& rBuiltin )
-:   ImplFontData( GetDevFontAttributes(rBuiltin), PDF_FONT_MAGIC ),
+:   PhysicalFontFace( GetDevFontAttributes(rBuiltin), PDF_FONT_MAGIC ),
     mrBuiltin( rBuiltin )
 {}
 
@@ -2298,13 +2298,13 @@ ImplDevFontList* PDFWriterImpl::filterDevFontList( ImplDevFontList* pFontList )
     if( !m_bIsPDF_A1 && !m_bEmbedStandardFonts)
         for( unsigned int i = 0; i < SAL_N_ELEMENTS(m_aBuiltinFonts); i++ )
         {
-            ImplFontData* pNewData = new ImplPdfBuiltinFontData( m_aBuiltinFonts[i] );
+            PhysicalFontFace* pNewData = new ImplPdfBuiltinFontData( m_aBuiltinFonts[i] );
             pFiltered->Add( pNewData );
         }
     return pFiltered;
 }
 
-bool PDFWriterImpl::isBuiltinFont( const ImplFontData* pFont ) const
+bool PDFWriterImpl::isBuiltinFont( const PhysicalFontFace* pFont ) const
 {
     const ImplPdfBuiltinFontData* pFD = GetPdfFontData( pFont );
     return (pFD != NULL);
@@ -3086,7 +3086,7 @@ bool PDFWriterImpl::emitTilings()
     return true;
 }
 
-sal_Int32 PDFWriterImpl::emitBuiltinFont( const ImplFontData* pFont, sal_Int32 nFontObject )
+sal_Int32 PDFWriterImpl::emitBuiltinFont( const PhysicalFontFace* pFont, sal_Int32 nFontObject )
 {
     const ImplPdfBuiltinFontData* pFD = GetPdfFontData( pFont );
     if( !pFD )
@@ -3110,7 +3110,7 @@ sal_Int32 PDFWriterImpl::emitBuiltinFont( const ImplFontData* pFont, sal_Int32 n
     return nFontObject;
 }
 
-std::map< sal_Int32, sal_Int32 > PDFWriterImpl::emitSystemFont( const ImplFontData* pFont, EmbedFont& rEmbed )
+std::map< sal_Int32, sal_Int32 > PDFWriterImpl::emitSystemFont( const PhysicalFontFace* pFont, EmbedFont& rEmbed )
 {
     std::map< sal_Int32, sal_Int32 > aRet;
     if( isBuiltinFont( pFont ) )
@@ -3259,7 +3259,7 @@ struct FontException : public std::exception
 };
 
 // TODO: always subset instead of embedding the full font => this method becomes obsolete then
-std::map< sal_Int32, sal_Int32 > PDFWriterImpl::emitEmbeddedFont( const ImplFontData* pFont, EmbedFont& rEmbed )
+std::map< sal_Int32, sal_Int32 > PDFWriterImpl::emitEmbeddedFont( const PhysicalFontFace* pFont, EmbedFont& rEmbed )
 {
     std::map< sal_Int32, sal_Int32 > aRet;
     if( isBuiltinFont( pFont ) )
@@ -3944,7 +3944,7 @@ sal_Int32 PDFWriterImpl::createToUnicodeCMap( sal_uInt8* pEncoding,
     return nStream;
 }
 
-sal_Int32 PDFWriterImpl::emitFontDescriptor( const ImplFontData* pFont, FontSubsetInfo& rInfo, sal_Int32 nSubsetID, sal_Int32 nFontStream )
+sal_Int32 PDFWriterImpl::emitFontDescriptor( const PhysicalFontFace* pFont, FontSubsetInfo& rInfo, sal_Int32 nSubsetID, sal_Int32 nFontStream )
 {
     OStringBuffer aLine( 1024 );
     // get font flags, see PDF reference 1.4 p. 358
@@ -4249,7 +4249,7 @@ bool PDFWriterImpl::emitFonts()
             }
             else
             {
-                const ImplFontData* pFont = it->first;
+                const PhysicalFontFace* pFont = it->first;
                 rtl::OStringBuffer aErrorComment( 256 );
                 aErrorComment.append( "CreateFontSubset failed for font \"" );
                 aErrorComment.append( OUStringToOString( pFont->GetFamilyName(), RTL_TEXTENCODING_UTF8 ) );
@@ -6838,7 +6838,7 @@ sal_Int32 PDFWriterImpl::getSystemFont( const Font& i_rFont )
     getReferenceDevice()->SetFont( i_rFont );
     getReferenceDevice()->ImplNewFont();
 
-    const ImplFontData* pDevFont = m_pReferenceDevice->mpFontEntry->maFontSelData.mpFontData;
+    const PhysicalFontFace* pDevFont = m_pReferenceDevice->mpFontEntry->maFontSelData.mpFontData;
     sal_Int32 nFontID = 0;
     FontEmbedData::iterator it = m_aSystemFonts.find( pDevFont );
     if( it != m_aSystemFonts.end() )
@@ -6863,14 +6863,14 @@ void PDFWriterImpl::registerGlyphs( int nGlyphs,
                                     sal_Int32* pUnicodesPerGlyph,
                                     sal_uInt8* pMappedGlyphs,
                                     sal_Int32* pMappedFontObjects,
-                                    const ImplFontData* pFallbackFonts[] )
+                                    const PhysicalFontFace* pFallbackFonts[] )
 {
-    const ImplFontData* pDevFont = m_pReferenceDevice->mpFontEntry->maFontSelData.mpFontData;
+    const PhysicalFontFace* pDevFont = m_pReferenceDevice->mpFontEntry->maFontSelData.mpFontData;
     sal_Ucs* pCurUnicode = pUnicodes;
     for( int i = 0; i < nGlyphs; pCurUnicode += pUnicodesPerGlyph[i] , i++ )
     {
         const int nFontGlyphId = pGlyphs[i] & (GF_IDXMASK | GF_ISCHAR | GF_GSUB);
-        const ImplFontData* pCurrentFont = pFallbackFonts[i] ? pFallbackFonts[i] : pDevFont;
+        const PhysicalFontFace* pCurrentFont = pFallbackFonts[i] ? pFallbackFonts[i] : pDevFont;
 
         if( isBuiltinFont( pCurrentFont ) )
         {
@@ -7308,7 +7308,7 @@ void PDFWriterImpl::drawLayout( SalLayout& rLayout, const String& rText, bool bT
     sal_Int32 pUnicodesPerGlyph[nMaxGlyphs];
     int pCharPosAry[nMaxGlyphs];
     sal_Int32 nAdvanceWidths[nMaxGlyphs];
-    const ImplFontData* pFallbackFonts[nMaxGlyphs];
+    const PhysicalFontFace* pFallbackFonts[nMaxGlyphs];
     bool bVertical = m_aCurrentPDFState.m_aFont.IsVertical();
     int nGlyphs;
     int nIndex = 0;
diff --git a/vcl/source/gdi/pdfwriter_impl.hxx b/vcl/source/gdi/pdfwriter_impl.hxx
index 8e1ba1d..36429a0 100644
--- a/vcl/source/gdi/pdfwriter_impl.hxx
+++ b/vcl/source/gdi/pdfwriter_impl.hxx
@@ -350,7 +350,7 @@ public:
         FontEmitList        m_aSubsets;
         FontMapping         m_aMapping;
     };
-    typedef std::map< const ImplFontData*, FontSubset > FontSubsetData;
+    typedef std::map< const PhysicalFontFace*, FontSubset > FontSubsetData;
     struct EmbedCode
     {
         sal_Ucs             m_aUnicode;
@@ -369,7 +369,7 @@ public:
 
         EmbedFont() : m_nNormalFontID( 0 ) {}
     };
-    typedef std::map< const ImplFontData*, EmbedFont > FontEmbedData;
+    typedef std::map< const PhysicalFontFace*, EmbedFont > FontEmbedData;
 
     struct PDFDest
     {
@@ -838,7 +838,7 @@ i12626
     void appendLiteralStringEncrypt( rtl::OStringBuffer& rInString, const sal_Int32 nInObjectNumber, rtl::OStringBuffer& rOutBuffer );
 
     /* creates fonts and subsets that will be emitted later */
-    void registerGlyphs( int nGlyphs, sal_GlyphId* pGlyphs, sal_Int32* pGlpyhWidths, sal_Ucs* pUnicodes, sal_Int32* pUnicodesPerGlyph, sal_uInt8* pMappedGlyphs, sal_Int32* pMappedFontObjects, const ImplFontData* pFallbackFonts[] );
+    void registerGlyphs( int nGlyphs, sal_GlyphId* pGlyphs, sal_Int32* pGlpyhWidths, sal_Ucs* pUnicodes, sal_Int32* pUnicodesPerGlyph, sal_uInt8* pMappedGlyphs, sal_Int32* pMappedFontObjects, const PhysicalFontFace* pFallbackFonts[] );
 
     /*  emits a text object according to the passed layout */
     /* TODO: remove rText as soon as SalLayout will change so that rText is not necessary anymore */
@@ -879,13 +879,13 @@ i12626
     /* writes all gradient patterns */
     bool emitGradients();
     /* writes a builtin font object and returns its objectid (or 0 in case of failure ) */
-    sal_Int32 emitBuiltinFont( const ImplFontData*, sal_Int32 nObject = -1 );
+    sal_Int32 emitBuiltinFont( const PhysicalFontFace*, sal_Int32 nObject = -1 );
     /* writes a type1 embedded font object and returns its mapping from font ids to object ids (or 0 in case of failure ) */
-    std::map< sal_Int32, sal_Int32 > emitEmbeddedFont( const ImplFontData*, EmbedFont& );
+    std::map< sal_Int32, sal_Int32 > emitEmbeddedFont( const PhysicalFontFace*, EmbedFont& );
     /* writes a type1 system font object and returns its mapping from font ids to object ids (or 0 in case of failure ) */
-    std::map< sal_Int32, sal_Int32 > emitSystemFont( const ImplFontData*, EmbedFont& );
+    std::map< sal_Int32, sal_Int32 > emitSystemFont( const PhysicalFontFace*, EmbedFont& );
     /* writes a font descriptor and returns its object id (or 0) */
-    sal_Int32 emitFontDescriptor( const ImplFontData*, FontSubsetInfo&, sal_Int32 nSubsetID, sal_Int32 nStream );
+    sal_Int32 emitFontDescriptor( const PhysicalFontFace*, FontSubsetInfo&, sal_Int32 nSubsetID, sal_Int32 nStream );
     /* writes a ToUnicode cmap, returns the corresponding stream object */
     sal_Int32 createToUnicodeCMap( sal_uInt8* pEncoding, sal_Ucs* pUnicodes, sal_Int32* pUnicodesPerGlyph, sal_Int32* pEncToUnicodeIndex, int nGlyphs );
 
@@ -1081,7 +1081,7 @@ public:
     ImplDevFontList* filterDevFontList( ImplDevFontList* pFontList );
     /*  for OutputDevice: get layout for builtin fonts
      */
-    bool isBuiltinFont( const ImplFontData* ) const;
+    bool isBuiltinFont( const PhysicalFontFace* ) const;
     SalLayout* GetTextLayout( ImplLayoutArgs& rArgs, FontSelectPattern* pFont );
     void getFontMetric( FontSelectPattern* pFont, ImplFontMetricData* pMetric ) const;
 
diff --git a/vcl/source/gdi/sallayout.cxx b/vcl/source/gdi/sallayout.cxx
index f6fe820..7cc160a 100644
--- a/vcl/source/gdi/sallayout.cxx
+++ b/vcl/source/gdi/sallayout.cxx
@@ -792,7 +792,7 @@ bool SalLayout::IsSpacingGlyph( sal_GlyphId nGlyph ) const
 
 // -----------------------------------------------------------------------
 
-const ImplFontData* SalLayout::GetFallbackFontData( sal_GlyphId /*nGlyphId*/ ) const
+const PhysicalFontFace* SalLayout::GetFallbackFontData( sal_GlyphId /*nGlyphId*/ ) const
 {
     return NULL;
 }
@@ -1459,7 +1459,7 @@ void GenericSalLayout::SortGlyphItems()
 
 // =======================================================================
 
-MultiSalLayout::MultiSalLayout( SalLayout& rBaseLayout, const ImplFontData* pBaseFont )
+MultiSalLayout::MultiSalLayout( SalLayout& rBaseLayout, const PhysicalFontFace* pBaseFont )
 :   SalLayout()
 ,   mnLevel( 1 )
 ,   mbInComplete( false )
@@ -1487,7 +1487,7 @@ MultiSalLayout::~MultiSalLayout()
 // -----------------------------------------------------------------------
 
 bool MultiSalLayout::AddFallback( SalLayout& rFallback,
-    ImplLayoutRuns& rFallbackRuns, const ImplFontData* pFallbackFont )
+    ImplLayoutRuns& rFallbackRuns, const PhysicalFontFace* pFallbackFont )
 {
     if( mnLevel >= MAX_FALLBACK )
         return false;
@@ -1888,7 +1888,7 @@ void MultiSalLayout::InitFont() const
 
 // -----------------------------------------------------------------------
 
-const ImplFontData* MultiSalLayout::GetFallbackFontData( sal_GlyphId nGlyphId ) const
+const PhysicalFontFace* MultiSalLayout::GetFallbackFontData( sal_GlyphId nGlyphId ) const
 {
     int nFallbackLevel = (nGlyphId & GF_FONTMASK) >> GF_FONTSHIFT;
     return mpFallbackFonts[ nFallbackLevel ];
diff --git a/vcl/win/source/gdi/salgdi3.cxx b/vcl/win/source/gdi/salgdi3.cxx
index 59ee078..963ea3a 100644
--- a/vcl/win/source/gdi/salgdi3.cxx
+++ b/vcl/win/source/gdi/salgdi3.cxx
@@ -465,7 +465,7 @@ public:
     bool FindFontSubstitute( FontSelectPattern&, rtl::OUString& rMissingChars ) const;
 private:
     HDC mhDC;
-    bool HasMissingChars( const ImplFontData*, const rtl::OUString& rMissingChars ) const;
+    bool HasMissingChars( const PhysicalFontFace*, const rtl::OUString& rMissingChars ) const;
 };
 
 inline WinGlyphFallbackSubstititution::WinGlyphFallbackSubstititution( HDC hDC )
@@ -476,7 +476,7 @@ void ImplGetLogFontFromFontSelect( HDC, const FontSelectPattern*,
     LOGFONTW&, bool /*bTestVerticalAvail*/ );
 
 // does a font face hold the given missing characters?
-bool WinGlyphFallbackSubstititution::HasMissingChars( const ImplFontData* pFace, const rtl::OUString& rMissingChars ) const
+bool WinGlyphFallbackSubstititution::HasMissingChars( const PhysicalFontFace* pFace, const rtl::OUString& rMissingChars ) const
 {
     const ImplWinFontData* pWinFont = static_cast<const ImplWinFontData*>(pFace);
     const ImplFontCharMap* pCharMap = pWinFont->GetImplFontCharMap();
@@ -570,7 +570,7 @@ bool WinGlyphFallbackSubstititution::FindFontSubstitute( FontSelectPattern& rFon
     /*const*/ ImplDevFontListData* pDevFont = findDevFontListByLocale(*pDevFontList, aLocale);
     if( pDevFont )
     {
-        const ImplFontData* pFace = pDevFont->FindBestFontFace( rFontSelData );
+        const PhysicalFontFace* pFace = pDevFont->FindBestFontFace( rFontSelData );
         if( HasMissingChars( pFace, rMissingChars ) )
         {
             rFontSelData.maSearchName = pDevFont->GetSearchName();
@@ -584,7 +584,7 @@ bool WinGlyphFallbackSubstititution::FindFontSubstitute( FontSelectPattern& rFon
                     rFontSelData.meItalic, rFontSelData.maSearchName );
     if( pDevFont )
     {
-        const ImplFontData* pFace = pDevFont->FindBestFontFace( rFontSelData );
+        const PhysicalFontFace* pFace = pDevFont->FindBestFontFace( rFontSelData );
         if( HasMissingChars( pFace, rMissingChars ) )
         {
             rFontSelData.maSearchName = pDevFont->GetSearchName();
@@ -602,7 +602,7 @@ bool WinGlyphFallbackSubstititution::FindFontSubstitute( FontSelectPattern& rFon
 
     for( int i = 0; i < nTestFontCount; ++i )
     {
-        const ImplFontData* pFace = pTestFontList->Get( i );
+        const PhysicalFontFace* pFace = pTestFontList->Get( i );
         if( !HasMissingChars( pFace, rMissingChars ) )
             continue;
         rFontSelData.maSearchName = pFace->maName;
@@ -1143,7 +1143,7 @@ const void * GrFontData::getTable(unsigned int name, size_t *len) const
 
 ImplWinFontData::ImplWinFontData( const ImplDevFontAttributes& rDFS,
     int nHeight, BYTE eWinCharSet, BYTE nPitchAndFamily )
-:   ImplFontData( rDFS, 0 ),
+:   PhysicalFontFace( rDFS, 0 ),
     mnId( 0 ),
     mbDisableGlyphApi( false ),
     mbHasKoreanRange( false ),
@@ -2563,7 +2563,7 @@ int ScopedTrueTypeFont::open(void * pBuffer, sal_uInt32 nLen,
 }
 
 sal_Bool WinSalGraphics::CreateFontSubset( const rtl::OUString& rToFile,
-    const ImplFontData* pFont, long* pGlyphIDs, sal_uInt8* pEncoding,
+    const PhysicalFontFace* pFont, long* pGlyphIDs, sal_uInt8* pEncoding,
     sal_Int32* pGlyphWidths, int nGlyphCount, FontSubsetInfo& rInfo )
 {
     // TODO: use more of the central font-subsetting code, move stuff there if needed
@@ -2719,7 +2719,7 @@ sal_Bool WinSalGraphics::CreateFontSubset( const rtl::OUString& rToFile,
 
 //--------------------------------------------------------------------------
 
-const void* WinSalGraphics::GetEmbedFontData( const ImplFontData* pFont,
+const void* WinSalGraphics::GetEmbedFontData( const PhysicalFontFace* pFont,
     const sal_Unicode* pUnicodes, sal_Int32* pCharWidths,
     FontSubsetInfo& rInfo, long* pDataLen )
 {
@@ -2783,7 +2783,7 @@ void WinSalGraphics::FreeEmbedFontData( const void* pData, long /*nLen*/ )
 
 //--------------------------------------------------------------------------
 
-const Ucs2SIntMap* WinSalGraphics::GetFontEncodingVector( const ImplFontData* pFont, const Ucs2OStrMap** pNonEncoded )
+const Ucs2SIntMap* WinSalGraphics::GetFontEncodingVector( const PhysicalFontFace* pFont, const Ucs2OStrMap** pNonEncoded )
 {
     // TODO: even for builtin fonts we get here... why?
     if( !pFont->IsEmbeddable() )
@@ -2810,7 +2810,7 @@ const Ucs2SIntMap* WinSalGraphics::GetFontEncodingVector( const ImplFontData* pF
 
 //--------------------------------------------------------------------------
 
-void WinSalGraphics::GetGlyphWidths( const ImplFontData* pFont,
+void WinSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                      bool bVertical,
                                      Int32Vector& rWidths,
                                      Ucs2UIntMap& rUnicodeEnc )
diff --git a/vcl/win/source/gdi/winlayout.cxx b/vcl/win/source/gdi/winlayout.cxx
index 1df1a75..2486c45 100644
--- a/vcl/win/source/gdi/winlayout.cxx
+++ b/vcl/win/source/gdi/winlayout.cxx
@@ -3027,7 +3027,7 @@ bool ImplWinFontEntry::InitKashidaHandling( HDC hDC )
 
 // =======================================================================
 
-ImplFontData* ImplWinFontData::Clone() const
+PhysicalFontFace* ImplWinFontData::Clone() const
 {
     if( mpUnicodeMap )
         mpUnicodeMap->AddReference();
@@ -3035,7 +3035,7 @@ ImplFontData* ImplWinFontData::Clone() const
     if ( mpGraphiteData )
         mpGraphiteData->AddReference();
 #endif
-    ImplFontData* pClone = new ImplWinFontData( *this );
+    PhysicalFontFace* pClone = new ImplWinFontData( *this );
     return pClone;
 }
 


More information about the Libreoffice-commits mailing list
diff --git a/vcl/aqua/source/gdi/salatslayout.cxx b/vcl/aqua/source/gdi/salatslayout.cxx
index a8fc7c5..73182ed 100644
--- a/vcl/aqua/source/gdi/salatslayout.cxx
+++ b/vcl/aqua/source/gdi/salatslayout.cxx
@@ -69,7 +69,7 @@ public:
     virtual bool    GetGlyphOutlines( SalGraphics&, PolyPolyVector& ) const;
     virtual bool    GetBoundRect( SalGraphics&, Rectangle& ) const;
 
-    const ImplFontData* GetFallbackFontData( sal_GlyphId ) const;
+    const PhysicalFontFace* GetFallbackFontData( sal_GlyphId ) const;
 
     virtual void    InitFont() const;
     virtual void    MoveGlyph( int nStart, long nNewXPos );
@@ -127,7 +127,7 @@ class FallbackInfo
 public:
         FallbackInfo() : mnMaxLevel(0) {}
     int AddFallback( ATSUFontID );
-    const ImplFontData* GetFallbackFontData( int nLevel ) const;
+    const PhysicalFontFace* GetFallbackFontData( int nLevel ) const;
 
 private:
     const ImplMacFontData* maFontData[ MAX_FALLBACK ];
@@ -1110,9 +1110,9 @@ void ATSLayout::MoveGlyph( int /*nStart*/, long /*nNewXPos*/ ) {}
 void ATSLayout::DropGlyph( int /*nStart*/ ) {}
 void ATSLayout::Simplify( bool /*bIsBase*/ ) {}
 
 // get the ImplFontData for a glyph fallback font
 // for a glyphid that was returned by ATSLayout::GetNextGlyphs()
-const ImplFontData* ATSLayout::GetFallbackFontData( sal_GlyphId nGlyphId ) const
+const PhysicalFontFace* ATSLayout::GetFallbackFontData( sal_GlyphId nGlyphId ) const
 {
     // check if any fallback fonts were needed
     if( !mpFallbackInfo )
@@ -1138,7 +1138,7 @@ int FallbackInfo::AddFallback( ATSUFontID nFontId )
         return 0;
     // keep ATSU font id of fallback font
     maATSUFontId[ mnMaxLevel ] = nFontId;
     // find and cache the corresponding ImplFontData pointer
     const SystemFontList* pSFL = GetSalData()->mpFontList;
     const ImplMacFontData* pFontData = pSFL->GetFontDataFromId( nFontId );
     maFontData[ mnMaxLevel ] = pFontData;
@@ -1148,7 +1148,7 @@ int FallbackInfo::AddFallback( ATSUFontID nFontId )
 
 // -----------------------------------------------------------------------
 
-const ImplFontData* FallbackInfo::GetFallbackFontData( int nFallbackLevel ) const
+const PhysicalFontFace* FallbackInfo::GetFallbackFontData( int nFallbackLevel ) const
 {
     const ImplMacFontData* pFallbackFont = maFontData[ nFallbackLevel-1 ];
     return pFallbackFont;
@@ -1110,9 +1110,9 @@ void ATSLayout::MoveGlyph( int /*nStart*/, long /*nNewXPos*/ ) {}
 void ATSLayout::Simplify( bool /*bIsBase*/ ) {}
 
-// get the ImplFontData for a glyph fallback font
+// get the PhysicalFontFace for a glyph fallback font
 // for a glyphid that was returned by ATSLayout::GetNextGlyphs()
@@ -1138,7 +1138,7 @@ int FallbackInfo::AddFallback( ATSUFontID nFontId )
     // keep ATSU font id of fallback font
     maATSUFontId[ mnMaxLevel ] = nFontId;
-    // find and cache the corresponding ImplFontData pointer
+    // find and cache the corresponding PhysicalFontFace pointer
     const SystemFontList* pSFL = GetSalData()->mpFontList;
     const ImplMacFontData* pFontData = pSFL->GetFontDataFromId( nFontId );
diff --git a/vcl/aqua/source/gdi/salgdi.cxx b/vcl/aqua/source/gdi/salgdi.cxx
index 933b139..05c970d 100644
--- a/vcl/aqua/source/gdi/salgdi.cxx
+++ b/vcl/aqua/source/gdi/salgdi.cxx
@@ -77,7 +77,7 @@ typedef std::vector<unsigned char> ByteVector;
 // =======================================================================
 
 ImplMacFontData::ImplMacFontData( const ImplDevFontAttributes& rDFA, ATSUFontID nFontId )
-:   ImplFontData( rDFA, 0 )
+:   PhysicalFontFace( rDFA, 0 )
 ,   mnFontId( nFontId )
 ,   mpCharMap( NULL )
 ,   mbOs2Read( false )
@@ -104,7 +104,7 @@ sal_IntPtr ImplMacFontData::GetFontId() const
 
 // -----------------------------------------------------------------------
 
-ImplFontData* ImplMacFontData::Clone() const
+PhysicalFontFace* ImplMacFontData::Clone() const
 {
     ImplMacFontData* pClone = new ImplMacFontData(*this);
     if( mpCharMap )
@@ -1711,7 +1711,7 @@ void AquaSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
     if (pSalData->mpFontList == NULL)
         pSalData->mpFontList = new SystemFontList();
 
     // Copy all ImplFontData objects contained in the SystemFontList
     pSalData->mpFontList->AnnounceFonts( *pFontList );
 }
 
@@ -2072,7 +2072,7 @@ static void FakeDirEntry( FourCharCode eFCC, ByteCount nOfs, ByteCount nLen,
     rpDest += 16;
 }
 
-static bool GetRawFontData( const ImplFontData* pFontData,
+static bool GetRawFontData( const PhysicalFontFace* pFontData,
     ByteVector& rBuffer, bool* pJustCFF )
 {
     const ImplMacFontData* pMacFont = static_cast<const ImplMacFontData*>(pFontData);
@@ -2222,7 +2222,7 @@ static bool GetRawFontData( const ImplFontData* pFontData,
 }
 
 sal_Bool AquaSalGraphics::CreateFontSubset( const rtl::OUString& rToFile,
-    const ImplFontData* pFontData, long* pGlyphIDs, sal_uInt8* pEncoding,
+    const PhysicalFontFace* pFontData, long* pGlyphIDs, sal_uInt8* pEncoding,
     sal_Int32* pGlyphWidths, int nGlyphCount, FontSubsetInfo& rInfo )
 {
     // TODO: move more of the functionality here into the generic subsetter code
@@ -2356,7 +2356,7 @@ sal_Bool AquaSalGraphics::CreateFontSubset( const rtl::OUString& rToFile,
 
 // -----------------------------------------------------------------------
 
-void AquaSalGraphics::GetGlyphWidths( const ImplFontData* pFontData, bool bVertical,
+void AquaSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFontData, bool bVertical,
     Int32Vector& rGlyphWidths, Ucs2UIntMap& rUnicodeEnc )
 {
     rGlyphWidths.clear();
@@ -2428,14 +2428,14 @@ void AquaSalGraphics::GetGlyphWidths( const ImplFontData* pFontData, bool bVerti
 // -----------------------------------------------------------------------
 
 const Ucs2SIntMap* AquaSalGraphics::GetFontEncodingVector(
-    const ImplFontData*, const Ucs2OStrMap** /*ppNonEncoded*/ )
+    const PhysicalFontFace*, const Ucs2OStrMap** /*ppNonEncoded*/ )
 {
     return NULL;
 }
 
 // -----------------------------------------------------------------------
 
-const void* AquaSalGraphics::GetEmbedFontData( const ImplFontData*,
+const void* AquaSalGraphics::GetEmbedFontData( const PhysicalFontFace*,
                               const sal_Ucs* /*pUnicodes*/,
                               sal_Int32* /*pWidths*/,
                               FontSubsetInfo&,
@@ -1711,7 +1711,7 @@ void AquaSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
         pSalData->mpFontList = new SystemFontList();
 
-    // Copy all ImplFontData objects contained in the SystemFontList
+    // Copy all PhysicalFontFace objects contained in the SystemFontList
     pSalData->mpFontList->AnnounceFonts( *pFontList );
 }
diff --git a/vcl/generic/print/genpspgraphics.cxx b/vcl/generic/print/genpspgraphics.cxx
index 95aed99..78a6c1e 100644
--- a/vcl/generic/print/genpspgraphics.cxx
+++ b/vcl/generic/print/genpspgraphics.cxx
@@ -544,7 +544,7 @@ void GenPspGraphics::invert(long,long,long,long,SalInvert)
 
 //==========================================================================
 
-class ImplPspFontData : public ImplFontData
+class ImplPspFontData : public PhysicalFontFace
 {
 private:
     enum { PSPFD_MAGIC = 0xb5bf01f0 };
@@ -553,15 +553,15 @@ private:
 public:
                             ImplPspFontData( const psp::FastPrintFontInfo& );
     virtual sal_IntPtr      GetFontId() const { return mnFontId; }
-    virtual ImplFontData*   Clone() const { return new ImplPspFontData( *this ); }
+    virtual PhysicalFontFace*   Clone() const { return new ImplPspFontData( *this ); }
     virtual ImplFontEntry*  CreateFontInstance( FontSelectPattern& ) const;
-    static bool             CheckFontData( const ImplFontData& r ) { return r.CheckMagic( PSPFD_MAGIC ); }
+    static bool             CheckFontData( const PhysicalFontFace& r ) { return r.CheckMagic( PSPFD_MAGIC ); }
 };
 
 //--------------------------------------------------------------------------
 
 ImplPspFontData::ImplPspFontData( const psp::FastPrintFontInfo& rInfo )
-:   ImplFontData( GenPspGraphics::Info2DevFontAttributes(rInfo), PSPFD_MAGIC ),
+:   PhysicalFontFace( GenPspGraphics::Info2DevFontAttributes(rInfo), PSPFD_MAGIC ),
     mnFontId( rInfo.m_nID )
 {}
 
@@ -1040,7 +1040,7 @@ SalLayout* GenPspGraphics::GetTextLayout( ImplLayoutArgs& rArgs, int nFallbackLe
 
 sal_Bool GenPspGraphics::CreateFontSubset(
                                    const rtl::OUString& rToFile,
-                                   const ImplFontData* pFont,
+                                   const PhysicalFontFace* pFont,
                                    sal_Int32* pGlyphIDs,
                                    sal_uInt8* pEncoding,
                                    sal_Int32* pWidths,
@@ -1052,7 +1052,7 @@ sal_Bool GenPspGraphics::CreateFontSubset(
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
 
     psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
@@ -1068,20 +1068,20 @@ sal_Bool GenPspGraphics::CreateFontSubset(
 
 //--------------------------------------------------------------------------
 
-const Ucs2SIntMap* GenPspGraphics::GetFontEncodingVector( const ImplFontData* pFont, const Ucs2OStrMap** pNonEncoded )
+const Ucs2SIntMap* GenPspGraphics::GetFontEncodingVector( const PhysicalFontFace* pFont, const Ucs2OStrMap** pNonEncoded )
 {
     // in this context the pFont->GetFontId() is a valid PSP
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetFontEncodingVector( aFont, pNonEncoded );
 }
 
 //--------------------------------------------------------------------------
 
-void GenPspGraphics::GetGlyphWidths( const ImplFontData* pFont,
+void GenPspGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                   bool bVertical,
                                   Int32Vector& rWidths,
                                   Ucs2UIntMap& rUnicodeEnc )
@@ -1090,7 +1090,7 @@ void GenPspGraphics::GetGlyphWidths( const ImplFontData* pFont,
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     GenPspGraphics::DoGetGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );
 }
@@ -1436,13 +1436,13 @@ void GenPspGraphics::FreeEmbedFontData( const void* pData, long nLen )
     DoFreeEmbedFontData( pData, nLen );
 }
 
-const void* GenPspGraphics::GetEmbedFontData( const ImplFontData* pFont, const sal_Ucs* pUnicodes, sal_Int32* pWidths, FontSubsetInfo& rInfo, long* pDataLen )
+const void* GenPspGraphics::GetEmbedFontData( const PhysicalFontFace* pFont, const sal_Ucs* pUnicodes, sal_Int32* pWidths, FontSubsetInfo& rInfo, long* pDataLen )
 {
     // in this context the pFont->GetFontId() is a valid PSP
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     return DoGetEmbedFontData( aFont, pUnicodes, pWidths, rInfo, pDataLen );
 }
@@ -1052,7 +1052,7 @@ sal_Bool GenPspGraphics::CreateFontSubset(
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
 
@@ -1068,20 +1068,20 @@ sal_Bool GenPspGraphics::CreateFontSubset(
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetFontEncodingVector( aFont, pNonEncoded );
@@ -1090,7 +1090,7 @@ void GenPspGraphics::GetGlyphWidths( const ImplFontData* pFont,
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     GenPspGraphics::DoGetGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );
@@ -1436,13 +1436,13 @@ void GenPspGraphics::FreeEmbedFontData( const void* pData, long nLen )
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     return DoGetEmbedFontData( aFont, pUnicodes, pWidths, rInfo, pDataLen );
diff --git a/vcl/headless/svptext.cxx b/vcl/headless/svptext.cxx
index 2eecfbd..1eee27a 100644
--- a/vcl/headless/svptext.cxx
+++ b/vcl/headless/svptext.cxx
@@ -373,7 +373,7 @@ bool SvpSalGraphics::AddTempDevFont( ImplDevFontList*,
 
 sal_Bool SvpSalGraphics::CreateFontSubset(
     const rtl::OUString& rToFile,
-    const ImplFontData* pFont,
+    const PhysicalFontFace* pFont,
     sal_Int32* pGlyphIDs,
     sal_uInt8* pEncoding,
     sal_Int32* pWidths,
@@ -385,7 +385,7 @@ sal_Bool SvpSalGraphics::CreateFontSubset(
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
 
     psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
@@ -401,13 +401,13 @@ sal_Bool SvpSalGraphics::CreateFontSubset(
 
 // ---------------------------------------------------------------------------
 
-const Ucs2SIntMap* SvpSalGraphics::GetFontEncodingVector( const ImplFontData* pFont, const Ucs2OStrMap** pNonEncoded )
+const Ucs2SIntMap* SvpSalGraphics::GetFontEncodingVector( const PhysicalFontFace* pFont, const Ucs2OStrMap** pNonEncoded )
 {
     // in this context the pFont->GetFontId() is a valid PSP
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetFontEncodingVector( aFont, pNonEncoded );
 }
@@ -415,7 +415,7 @@ const Ucs2SIntMap* SvpSalGraphics::GetFontEncodingVector( const ImplFontData* pF
 // ---------------------------------------------------------------------------
 
 const void* SvpSalGraphics::GetEmbedFontData(
-    const ImplFontData* pFont,
+    const PhysicalFontFace* pFont,
     const sal_Ucs* pUnicodes,
     sal_Int32* pWidths,
     FontSubsetInfo& rInfo,
@@ -426,7 +426,7 @@ const void* SvpSalGraphics::GetEmbedFontData(
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetEmbedFontData( aFont, pUnicodes, pWidths, rInfo, pDataLen );
 }
@@ -438,7 +438,7 @@ void SvpSalGraphics::FreeEmbedFontData( const void* pData, long nLen )
     GenPspGraphics::DoFreeEmbedFontData( pData, nLen );
 }
 
-void SvpSalGraphics::GetGlyphWidths( const ImplFontData* pFont,
+void SvpSalGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                    bool bVertical,
                                    Int32Vector& rWidths,
                                    Ucs2UIntMap& rUnicodeEnc )
@@ -447,7 +447,7 @@ void SvpSalGraphics::GetGlyphWidths( const ImplFontData* pFont,
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     GenPspGraphics::DoGetGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );
 }
@@ -385,7 +385,7 @@ sal_Bool SvpSalGraphics::CreateFontSubset(
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
 
@@ -401,13 +401,13 @@ sal_Bool SvpSalGraphics::CreateFontSubset(
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetFontEncodingVector( aFont, pNonEncoded );
@@ -426,7 +426,7 @@ const void* SvpSalGraphics::GetEmbedFontData(
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetEmbedFontData( aFont, pUnicodes, pWidths, rInfo, pDataLen );
@@ -447,7 +447,7 @@ void SvpSalGraphics::GetGlyphWidths( const ImplFontData* pFont,
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     GenPspGraphics::DoGetGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );
diff --git a/vcl/inc/outfont.hxx b/vcl/inc/outfont.hxx
index 19c2c3a..70398d6 100644
--- a/vcl/inc/outfont.hxx
+++ b/vcl/inc/outfont.hxx
@@ -107,19 +107,19 @@ public: // TODO: hide members behind accessor methods
 };
 
 // ----------------
-// - ImplFontData -
+// - PhysicalFontFace -
 // ----------------
-// TODO: rename ImplFontData to PhysicalFontFace
+// DONE: rename ImplFontData to PhysicalFontFace
 // TODO: no more direct access to members
 // TODO: add reference counting
 // TODO: get rid of height/width for scalable fonts
 // TODO: make cloning cheaper
 
 // abstract base class for physical font faces
-class VCL_PLUGIN_PUBLIC ImplFontData : public ImplDevFontAttributes
+class VCL_PLUGIN_PUBLIC PhysicalFontFace : public ImplDevFontAttributes
 {
 public:
     // by using an ImplFontData object as a factory for its corresponding
     // ImplFontEntry an ImplFontEntry can be extended to cache device and
     // font instance specific data
     virtual ImplFontEntry*  CreateFontInstance( FontSelectPattern& ) const = 0;
@@ -130,17 +130,17 @@ public:
     int                     GetFontMagic() const        { return mnMagic; }
     bool                    IsScalable() const          { return (mnHeight == 0); }
     bool                    CheckMagic( int n ) const   { return (n == mnMagic); }
-    ImplFontData*           GetNextFace() const         { return mpNext; }
-    ImplFontData*           CreateAlias() const         { return Clone(); }
+    PhysicalFontFace*       GetNextFace() const         { return mpNext; }
+    PhysicalFontFace*       CreateAlias() const         { return Clone(); }
 
     bool                    IsBetterMatch( const FontSelectPattern&, FontMatchStatus& ) const;
-    StringCompare           CompareWithSize( const ImplFontData& ) const;
-    StringCompare           CompareIgnoreSize( const ImplFontData& ) const;
-    virtual                 ~ImplFontData() {}
-    virtual ImplFontData*   Clone() const = 0;
+    StringCompare           CompareWithSize( const PhysicalFontFace& ) const;
+    StringCompare           CompareIgnoreSize( const PhysicalFontFace& ) const;
+    virtual                 ~PhysicalFontFace() {}
+    virtual PhysicalFontFace* Clone() const = 0;
 
 protected:
-    explicit                ImplFontData( const ImplDevFontAttributes&, int nMagic );
+    explicit                PhysicalFontFace( const ImplDevFontAttributes&, int nMagic );
     void                    SetBitmapSize( int nW, int nH ) { mnWidth=nW; mnHeight=nH; }
 
     long                    mnWidth;    // Width (in pixels)
@@ -149,7 +149,7 @@ protected:
 private:
 friend class ImplDevFontListData;
     const int               mnMagic;    // poor man's RTTI
-    ImplFontData*           mpNext;
+    PhysicalFontFace*       mpNext;
 };
 
 // ----------------------
@@ -160,9 +160,9 @@ class FontSelectPattern : public ImplFontAttributes
 {
 public:
                         FontSelectPattern( const Font&, const String& rSearchName,
-                            const Size&, float fExactHeight );
-                        FontSelectPattern( const ImplFontData&, const Size&,
-                            float fExactHeight, int nOrientation, bool bVertical );
+                                           const Size&, float fExactHeight );
+                        FontSelectPattern( const PhysicalFontFace&, const Size&,
+                                           float fExactHeight, int nOrientation, bool bVertical );
 
 public: // TODO: change to private
     String              maTargetName;       // name of the font name token that is chosen
@@ -178,7 +178,7 @@ public: // TODO: change to private
     bool                mbEmbolden;         // Force emboldening
     ItalicMatrix        maItalicMatrix;     // Force matrix for slant
 
-    const ImplFontData* mpFontData;         // a matching ImplFontData object
+    const PhysicalFontFace* mpFontData;         // a matching PhysicalFontFace object
     ImplFontEntry*      mpFontEntry;        // pointer to the resulting FontCache entry
 };
 
@@ -206,7 +206,7 @@ public:
     virtual                 ~ImplDevFontList();
 
     // fill the list with device fonts
-    void                    Add( ImplFontData* );
+    void                    Add( PhysicalFontFace* );
     void                    Clear();
     int                     Count() const { return maDevFontList.size(); }
 
@@ -238,7 +238,7 @@ protected:
         const rtl::OUString& rShortName) const;
     ImplDevFontListData*    ImplFindBySubstFontAttr( const utl::FontNameAttr& ) const;
     ImplDevFontListData*    ImplFindByAttributes(sal_uLong nSearchType, FontWeight, FontWidth,
-                                FontItalic, const rtl::OUString& rSearchFamily) const;
+                                                 FontItalic, const rtl::OUString& rSearchFamily) const;
     ImplDevFontListData*    FindDefaultFont() const;
 
 private:
@@ -256,8 +256,8 @@ private:
 
 struct ImplKernPairData
 {
-    sal_uInt16              mnChar1;
-    sal_uInt16              mnChar2;
+    sal_uInt16          mnChar1;
+    sal_uInt16          mnChar2;
     long                mnKern;
 };
 
@@ -107,19 +107,19 @@ public: // TODO: hide members behind accessor methods
 {
 public:
-    // by using an ImplFontData object as a factory for its corresponding
+    // by using an PhysicalFontFace object as a factory for its corresponding
     // ImplFontEntry an ImplFontEntry can be extended to cache device and
     // font instance specific data
diff --git a/vcl/ios/source/gdi/salgdi.cxx b/vcl/ios/source/gdi/salgdi.cxx
index 32cc9fb..2525086 100644
--- a/vcl/ios/source/gdi/salgdi.cxx
+++ b/vcl/ios/source/gdi/salgdi.cxx
@@ -100,7 +100,7 @@ void IosSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
     {
         pSalData->mpFontList = new SystemFontList();
     }
     // Copy all ImplFontData objects contained in the SystemFontList
     pSalData->mpFontList->AnnounceFonts( *pFontList );
 }
 
@@ -109,7 +109,7 @@ void IosSalGraphics::GetDevFontSubstList( OutputDevice* )
     // nothing to do since there are no device-specific fonts on Ios
 }
 
-const void* IosSalGraphics::GetEmbedFontData( const ImplFontData*,
+const void* IosSalGraphics::GetEmbedFontData( const PhysicalFontFace*,
                               const sal_Ucs* /*pUnicodes*/,
                               sal_Int32* /*pWidths*/,
                               FontSubsetInfo&,
@@ -118,7 +118,7 @@ const void* IosSalGraphics::GetEmbedFontData( const ImplFontData*,
     return NULL;
 }
 
-const Ucs2SIntMap* IosSalGraphics::GetFontEncodingVector(const ImplFontData*,
+const Ucs2SIntMap* IosSalGraphics::GetFontEncodingVector(const PhysicalFontFace*,
                                                           const Ucs2OStrMap** /*ppNonEncoded*/ )
 {
     return NULL;
@@ -159,7 +159,7 @@ sal_Bool IosSalGraphics::GetGlyphOutline( sal_GlyphId /*nGlyphId*/, basegfx::B2D
     return false;
 }
 
-void IosSalGraphics::GetGlyphWidths( const ImplFontData* /*pFontData*/, bool /*bVertical*/,
+void IosSalGraphics::GetGlyphWidths( const PhysicalFontFace* /*pFontData*/, bool /*bVertical*/,
                                       Int32Vector& /*rGlyphWidths*/, Ucs2UIntMap& /*rUnicodeEnc*/ )
 {
 }
@@ -187,7 +187,7 @@ const ImplFontCharMap* IosSalGraphics::GetImplFontCharMap() const
     return m_pCoreTextFontData->GetImplFontCharMap();
 }
 
-bool IosSalGraphics::GetRawFontData( const ImplFontData* pFontData,
+bool IosSalGraphics::GetRawFontData( const PhysicalFontFace* pFontData,
                      std::vector<unsigned char>& rBuffer, bool* pJustCFF )
 {
     const ImplCoreTextFontData* font_data = static_cast<const ImplCoreTextFontData*>(pFontData);
@@ -100,7 +100,7 @@ void IosSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
         pSalData->mpFontList = new SystemFontList();
     }
-    // Copy all ImplFontData objects contained in the SystemFontList
+    // Copy all PhysicalFontFace objects contained in the SystemFontList
     pSalData->mpFontList->AnnounceFonts( *pFontList );
 }
diff --git a/vcl/unx/generic/gdi/salgdi3.cxx b/vcl/unx/generic/gdi/salgdi3.cxx
index 04d2142..89e524e 100644
--- a/vcl/unx/generic/gdi/salgdi3.cxx
+++ b/vcl/unx/generic/gdi/salgdi3.cxx
@@ -792,7 +792,7 @@ SystemFontData X11SalGraphics::GetSysFontData( int nFallbacklevel ) const
 
 sal_Bool X11SalGraphics::CreateFontSubset(
                                    const rtl::OUString& rToFile,
-                                   const ImplFontData* pFont,
+                                   const PhysicalFontFace* pFont,
                                    sal_Int32* pGlyphIDs,
                                    sal_uInt8* pEncoding,
                                    sal_Int32* pWidths,
@@ -804,7 +804,7 @@ sal_Bool X11SalGraphics::CreateFontSubset(
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
 
     psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
@@ -820,13 +820,13 @@ sal_Bool X11SalGraphics::CreateFontSubset(
 
 //--------------------------------------------------------------------------
 
-const void* X11SalGraphics::GetEmbedFontData( const ImplFontData* pFont, const sal_Ucs* pUnicodes, sal_Int32* pWidths, FontSubsetInfo& rInfo, long* pDataLen )
+const void* X11SalGraphics::GetEmbedFontData( const PhysicalFontFace* pFont, const sal_Ucs* pUnicodes, sal_Int32* pWidths, FontSubsetInfo& rInfo, long* pDataLen )
 {
     // in this context the pFont->GetFontId() is a valid PSP
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetEmbedFontData( aFont, pUnicodes, pWidths, rInfo, pDataLen );
 }
@@ -840,20 +840,20 @@ void X11SalGraphics::FreeEmbedFontData( const void* pData, long nLen )
 
 //--------------------------------------------------------------------------
 
-const Ucs2SIntMap* X11SalGraphics::GetFontEncodingVector( const ImplFontData* pFont, const Ucs2OStrMap** pNonEncoded )
+const Ucs2SIntMap* X11SalGraphics::GetFontEncodingVector( const PhysicalFontFace* pFont, const Ucs2OStrMap** pNonEncoded )
 {
     // in this context the pFont->GetFontId() is a valid PSP
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetFontEncodingVector( aFont, pNonEncoded );
 }
 
 //--------------------------------------------------------------------------
 
-void X11SalGraphics::GetGlyphWidths( const ImplFontData* pFont,
+void X11SalGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
                                    bool bVertical,
                                    Int32Vector& rWidths,
                                    Ucs2UIntMap& rUnicodeEnc )
@@ -862,7 +862,7 @@ void X11SalGraphics::GetGlyphWidths( const ImplFontData* pFont,
     // font since they are the only ones left after the PDF
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
     // be to have the GlyphCache search for the ImplFontData pFont
     psp::fontID aFont = pFont->GetFontId();
     GenPspGraphics::DoGetGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );
 }
@@ -804,7 +804,7 @@ sal_Bool X11SalGraphics::CreateFontSubset(
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
 
@@ -820,13 +820,13 @@ sal_Bool X11SalGraphics::CreateFontSubset(
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetEmbedFontData( aFont, pUnicodes, pWidths, rInfo, pDataLen );
@@ -840,20 +840,20 @@ void X11SalGraphics::FreeEmbedFontData( const void* pData, long nLen )
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     return GenPspGraphics::DoGetFontEncodingVector( aFont, pNonEncoded );
@@ -862,7 +862,7 @@ void X11SalGraphics::GetGlyphWidths( const ImplFontData* pFont,
     // export has filtered its list of subsettable fonts (for
     // which this method was created). The correct way would
-    // be to have the GlyphCache search for the ImplFontData pFont
+    // be to have the GlyphCache search for the PhysicalFontFace pFont
     psp::fontID aFont = pFont->GetFontId();
     GenPspGraphics::DoGetGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );